#ifndef HARKTOOL4_IRPROVIDER_HPP
#define HARKTOOL4_IRPROVIDER_HPP

#include <vector>
#include <boost/shared_ptr.hpp>
#include <harkio2/harkconfig/Source.hpp>

namespace harktool4
{

/** @brief インパルス応答を提供するインターフェース.
 * ユーザーから指定された音源とマイク間のインバルス応答を返す機能を提供する。
 * ImpulseResponseListFileとTSPListFileでは、音源-マイク間インパルス応答を
 * 計算する方法が違うため、このインターフェースを実装したクラスで差を吸収する。
 */
class IRProvider
{
public:
    IRProvider() = default;
    IRProvider(const IRProvider&) = default;
    IRProvider& operator=(const IRProvider&) = default;
    virtual ~IRProvider()
    { }

    /** @brief 指定された音源番号、マイク番号に対応するインパルス応答を返す.
     * @param src_index 0始まりの音源番号
     * @param mic_index 0始まりのマイク番号
     * @return src_indexとmic_indexに対応するインパルス応答
     */
    virtual std::vector<float> GetIR(size_t src_index, size_t mic_index) = 0;
    virtual size_t GetNumSrc() = 0;
    virtual size_t GetNumMic() = 0;
    virtual std::vector<boost::shared_ptr<harkio2::harkconfig::Source>> GetSources() = 0;
    virtual boost::shared_ptr<std::vector<unsigned int>> GetSrcRelatedMicIndices() = 0;
};

}

#endif // HARKTOOL4_IRPROVIDER_HPP

